==> ucloud-ko-fileupload-3.0.5.tgz: package/src/u-fileupload/i18n.js <==
var language = {
  '替换': {
    enus: 'replace',
    zhcn: '替换',
    zhtw: '替換'
  },
  '上传': {
    enus: 'upload',
    zhcn: '上传',
    zhtw: '上傳'
  },
  '预览': {
    enus: 'preview',
    zhcn: '预览',
    zhtw: '預覽'
  },
  '下载': {
    enus: 'download',
    zhcn: '下载',
    zhtw: '下載'
  },
  '删除': {
    enus: 'delete',
    zhcn: '删除',
    zhtw: '刪除'
  },
  '删除后不可恢复，请确认！': {
    enus: 'The attachment cannot be recovered after deleted, do you want still want to delete it!',
    zhcn: '删除后不可恢复，请确认！',
    zhtw: '刪除後不可恢複，請確認！'
  },
  '上传出错': {
    enus: 'upload error',
    zhcn: '上传出错',
    zhtw: '上傳出錯'
  },
  '上传失败': {
    enus: 'upload failed',
    zhcn: '上传失败',
    zhtw: '上傳失敗'
  },
  '确定': {
    enus: 'ok',
    zhcn: '确定',
    zhtw: '確定'
  },
  '取消': {
    enus: 'cancel',
    zhcn: '取消',
    zhtw: '取消'
  },
  '附件': {
    enus: 'attachment',
    zhcn: '附件',
    zhtw: '附件'
  },
  '管理附件': {
    enus: 'attachments',
    zhcn: '管理附件',
    zhtw: '管理附件'
  },
  '等待上传': {
    enus: 'loading',
    zhcn: '等待上传',
    zhtw: '等待上傳'
  },
  '文件总数量不能超过：': {
    enus: 'The total number of attachments cannot exceed ',
    zhcn: '文件总数量不能超过',
    zhtw: '文件總數量不能超過'
  },
  '文件名不能包含下列字符：': {
    enus: 'The file name cannot include these charaters:',
    zhcn: '文件名不能包含下列字符',
    zhtw: '文件名不能包含下列字符'
  },
  '图片': {
    enus: 'image',
    zhcn: '图片',
    zhtw: '圖片'
  },
  '请选择图片！': {
    enus: 'Upload image only!',
    zhcn: '请选择图片！',
    zhtw: '請選擇圖片!'
  },
  '请选择100M以内的附件！': {
    enus: 'Attachment Max Size 100M!',
    zhcn: '请选择100M以内的附件！',
    zhtw: '請選擇100M以內的附件！'
  }
}
// 适配前后都有url参数的场景
function getQueryVariable (variable) {
  var url = window.location.href.split('?')
  var decodeFunc = unescape
  if (url.length > 1) {
    var theRequest = new Object()
    url.forEach(function(item){
      var params = item.split('&')
      params.forEach(param => {
        theRequest[param.split('=')[0]] = decodeFunc(param.split('=')[1])
      })
    })
    return theRequest[variable] || null
  } else {
    return null
  }
  return false
}
var locale = null
var getLang = function (key,option) {
  // option  fileLimit 配置文件大小
  // 如果url里带参数则直接用
  if (!locale) {
    var _locale = getQueryVariable('locale')
    if (_locale) {
      _locale = _locale.split('#')[0]
      if (['zh_CN', 'en_US', 'zh_TW'].indexOf(_locale) >= 0) {
        locale = _locale.replace('-', '').replace('_', '').toLowerCase()
      }
    }
  }
  if (document.cookie.indexOf('u_locale=en_US') >= 0) {
    locale = 'enus'
  } else if (document.cookie.indexOf('u_locale=zh_TW') >= 0) {
    locale = 'zhtw'
  }
  // 如果没有设置默认值
  if (!locale) {
    locale = 'zhcn'
  }
  if (locale !== 'zhcn') {
    if (!language[key]) {
      if (option && option.fileLimit) {
        language[key] = {
          enus: `Attachment Max Size ${option.fileLimit}M!`,
          zhcn: `请选择${option.fileLimit}M以内的附件！`,
          zhtw: `請選擇${option.fileLimit}M以內的附件！`  
        }
      }
    }
    return language[key][locale]  
  } else {
    return key
  }
}
export default getLang

==> ucloud-ko-fileupload-4.0.8.tgz: package/src/u-fileupload/i18n.js <==
var language = {
  '替换': {
    enus: 'replace',
    zhcn: '替换',
    zhtw: '替換'
  },
  '上传': {
    enus: 'upload',
    zhcn: '上传',
    zhtw: '上傳'
  },
  '预览': {
    enus: 'preview',
    zhcn: '预览',
    zhtw: '預覽'
  },
  '下载': {
    enus: 'download',
    zhcn: '下载',
    zhtw: '下載'
  },
  '删除': {
    enus: 'delete',
    zhcn: '删除',
    zhtw: '刪除'
  },
  '删除后不可恢复，请确认！': {
    enus: 'The attachment cannot be recovered after deleted, do you want still want to delete it!',
    zhcn: '删除后不可恢复，请确认！',
    zhtw: '刪除後不可恢複，請確認！'
  },
  '上传出错': {
    enus: 'upload error',
    zhcn: '上传出错',
    zhtw: '上傳出錯'
  },
  '上传失败': {
    enus: 'upload failed',
    zhcn: '上传失败',
    zhtw: '上傳失敗'
  },
  '确定': {
    enus: 'ok',
    zhcn: '确定',
    zhtw: '確定'
  },
  '取消': {
    enus: 'cancel',
    zhcn: '取消',
    zhtw: '取消'
  },
  '附件': {
    enus: 'attachment',
    zhcn: '附件',
    zhtw: '附件'
  },
  '管理附件': {
    enus: 'attachments',
    zhcn: '管理附件',
    zhtw: '管理附件'
  },
  '等待上传': {
    enus: 'loading',
    zhcn: '等待上传',
    zhtw: '等待上傳'
  },
  '文件总数量不能超过：': {
    enus: 'The total number of attachments cannot exceed ',
    zhcn: '文件总数量不能超过',
    zhtw: '文件總數量不能超過'
  },
  '文件名不能包含下列字符：': {
    enus: 'The file name cannot include these charaters:',
    zhcn: '文件名不能包含下列字符',
    zhtw: '文件名不能包含下列字符'
  },
  '图片': {
    enus: 'image',
    zhcn: '图片',
    zhtw: '圖片'
  },
  '请选择图片！': {
    enus: 'Upload image only!',
    zhcn: '请选择图片！',
    zhtw: '請選擇圖片!'
  },
  '请选择100M以内的附件！': {
    enus: 'Attachment Max Size 100M!',
    zhcn: '请选择100M以内的附件！',
    zhtw: '請選擇100M以內的附件！'
  },
  '信息': {
    enus: 'Information',
    zhcn: '信息',
    zhtw: '信息'
  }
}
// 适配前后都有url参数的场景
function getQueryVariable (variable) {
  var url = window.location.href.split('?')
  var decodeFunc = unescape
  if (url.length > 1) {
    var theRequest = new Object()
    url.forEach(function(item){
      var params = item.split('&')
      params.forEach(param => {
        theRequest[param.split('=')[0]] = decodeFunc(param.split('=')[1])
      })
    })
    return theRequest[variable] || null
  } else {
    return null
  }
  return false
}
var locale = null
var getLang = function (key,option) {
  // option  fileLimit 配置文件大小
  // 如果url里带参数则直接用
  if (!locale) {
    var _locale = getQueryVariable('locale')
    if (_locale) {
      _locale = _locale.split('#')[0]
      if (['zh_CN', 'en_US', 'zh_TW'].indexOf(_locale) >= 0) {
        locale = _locale.replace('-', '').replace('_', '').toLowerCase()
      }
    }
  }
  if (document.cookie.indexOf('locale=en_US') >= 0) {
    locale = 'enus'
  } else if (document.cookie.indexOf('locale=zh_TW') >= 0) {
    locale = 'zhtw'
  }
  // 如果没有设置默认值
  if (!locale) {
    locale = 'zhcn'
  }
  if (locale !== 'zhcn') {
    if (!language[key]) {
      if (option && option.fileLimit) {
        language[key] = {
          enus: `Attachment Max Size ${option.fileLimit}M!`,
          zhcn: `请选择${option.fileLimit}M以内的附件！`,
          zhtw: `請選擇${option.fileLimit}M以內的附件！`  
        }
      }
    }
    return language[key][locale]  
  } else {
    return key
  }
}
export default getLang
